@@ -27,7 +27,7 @@
 
 #include "kwqtutor.h"
 #include "kwordquiz.h"
-#include "version.h"
+#include "kwordquiz_version.h"
 
 static const char *description = I18N_NOOP("A powerful flashcard and vocabulary learning program");
 int main(int argc, char *argv[])
@@ -37,18 +37,18 @@ int main(int argc, char *argv[])
     KCrash::initialize();
     KLocalizedString::setApplicationDomain("kwordquiz");
     QApplication::setApplicationName(QStringLiteral("kwordquiz"));
-    QApplication::setApplicationVersion(KWQ_VERSION);
+    QApplication::setApplicationVersion(KWORDQUIZ_VERSION_STRING);
     QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
     QApplication::setApplicationDisplayName(i18n("kwordquiz"));
 
     KAboutData aboutData(QStringLiteral("kwordquiz"),
                          i18n("KWordQuiz"),
-                         KWQ_VERSION,
+                         KWORDQUIZ_VERSION_STRING,
                          i18n(description),
                          KAboutLicense::GPL_V2,
                          i18n("(c) 2003-2010, Peter Hedlund"),
                          QString(),
-                         QStringLiteral("http://edu.kde.org/kwordquiz"),
+                         QStringLiteral("https://kde.org/applications/education/kwordquiz"),
                          QStringLiteral("submit@bugs.kde.org"));
     aboutData.addAuthor(i18n("Peter Hedlund"), QString(), QStringLiteral("peter.hedlund@kdemail.net"));
     aboutData.addCredit(i18n("Anne-Marie Mahfouf"), i18n("KDE Edutainment Maintainer"), QStringLiteral("annma@kde.org"));
